Description Author(s) References
Decomposes a directed weighted graph into a directed acyclic flow, a local cyclic flow and a global cyclic flow as described in <doi:10.1109/MCSE.2012.91>
Maintainer: Edwin de Jonge edwindjonge@gmail.com (ORCID)
https://facultyweb.cs.wwu.edu/~johnsoj5/prepub/Hodge%20Tutorial.pdf
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.